@@ -338,7 +338,8 @@ struct slab_stats {
 #define PROXY_THREAD_STATS_FIELDS \
     X(proxy_conn_requests) \
     X(proxy_conn_errors) \
-    X(proxy_conn_oom)
+    X(proxy_conn_oom) \
+    X(proxy_req_active)
 #endif
 
 /**
@@ -494,6 +495,7 @@ struct settings {
     unsigned int ext_wbuf_size; /* read only note for the engine */
     unsigned int ext_compact_under; /* when fewer than this many pages, compact */
     unsigned int ext_drop_under; /* when fewer than this many pages, drop COLD items */
+    unsigned int ext_max_sleep; /* maximum sleep time for extstore bg threads, in us */
     double ext_max_frag; /* ideal maximum page fragmentation */
     double slab_automove_freeratio; /* % of memory to hold free as buffer */
     bool ext_drop_unread; /* skip unread items during compaction */
@@ -512,6 +514,7 @@ struct settings {
     rel_time_t ssl_last_cert_refresh_time; /* time of the last server certificate refresh */
     unsigned int ssl_wbuf_size; /* size of the write buffer used by ssl_sendmsg method */
     bool ssl_session_cache; /* enable SSL server session caching */
+    bool ssl_kernel_tls; /* enable server kTLS */
     int ssl_min_version; /* minimum SSL protocol version to accept */
 #endif
     int num_napi_ids;   /* maximum number of NAPI IDs */
@@ -715,7 +718,9 @@ typedef struct {
 #ifdef PROXY
     void *L;
     void *proxy_hooks;
-    void *proxy_stats;
+    void *proxy_user_stats;
+    void *proxy_int_stats;
+    uint32_t proxy_rng[4]; // fast per-thread rng for lua.
     // TODO: add ctx object so we can attach to queue.
 #endif
 } LIBEVENT_THREAD;
